@@ -1564,6 +1564,22 @@ class VariableClUpdateBinhostUnstableList(Variable):
     value = ["ftp://ftp.calculate-linux.ru/testing"]
 
 
+class VariableClUpdateBinhostBase(Variable):
+    """
+    Базовый бинарный хост, используемый для установки базовых пакетов
+    в небинарных сборочных дистрибутивах
+    """
+    value = ""
+
+
+class VariableClUpdateBinhostBaseSet(Variable):
+    """
+    Использовать или нет базовый бинарный хост
+    """
+    type = Variable.Types.Boolean
+    value = Variable.Off
+
+
 class VariableClUpdateBinhostStableSet(Variable):
     """
     Удлять лишние файлы из репозиториев (например созданные пользователем)
